Module output

Module output 

Enums

OutputFormat
Output format for CLI tools.

Functions

print_error
Print an error in the appropriate format and return the exit code.
print_json
Print a JSON value directly.
print_output
Print a value as either human text or JSON.